% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/flowls.R
\name{flowls}
\alias{flowls}
\title{List all possible flow paths in district heating network}
\usage{
flowls(sender = "A", acceptor = "B", maxcores = 2)
}
\arguments{
\item{sender}{identifier of the node which heat carrier flows out.
Type: any type that can be painlessly coerced to character by
\code{\link{as.character}}.}

\item{acceptor}{identifier of the node which heat carrier flows in. According to topology
of test bench considered this identifier should be unique.
Type: any type that can be painlessly coerced to character by
\code{\link{as.character}}.}

\item{maxcores}{maximum cores of CPU to use in parallel processing.
Type: \code{\link{assert_count}}.}
}
\value{
named \code{list} that contains integer vectors as its elements. The name
 of each element in the \code{list} is the name of \code{acceptor} associated
 with terminal node of district heating network. Each vector in the
 \code{list} represents an ordered sequence of indexes in \code{acceptor}
 that enumerates incoming edges from starting node to terminal one. The
 length of returned \code{list} is equal to number of terminal nodes for
 topology considered. Type: \code{\link{assert_list}}.
}
\description{
Find and list all possible paths of heat carrier flow (water) in the given
 topology of district heating system.
}
\details{
Only branched topology without cycles is considered where no more than one
incoming edge exists for every \code{acceptor} node. For instance,
\code{\link{m325testbench}} has permitted topology.

Though input arguments are natively vectorized their individual values
all relate to common part of district heating network, i.e. associated with
common object. It is due to isomorphism between vector representation and
directed graph of this network. For more details of isomorphic topology
description see \code{\link{m325testbench}}.

For possibly better performance, they search paths of heat carrier flow
in parallel leveraging the functionality of package \code{\link{parallel}}.
}
\examples{
\donttest{
# Find path from A to B in trivial line topology:
flowls("A", "B")

# $B
# [1] 1

# More complex example with two terminal nodes D and E:
flowls(c("A", "B", "B"), c("B", "D", "E"))

#$D
#[1] 1 2
#
#$E
#[1] 1 3

# All possible flow paths in test bench illustrated in `?m325testbench`:
all_paths <- list(
  c(12, 13, 11, 8, 4, 1),  # hereinafter indexes of acceptor nodes
  c(12, 13, 11, 8, 4, 2),
  c(12, 13, 11, 8, 6, 5,  3),
  c(12, 13, 11, 8, 6, 7),
  c(12, 13, 11, 8, 6, 9),
  c(12, 13, 11, 10),
  c(12, 13, 14, 15),
  c(12, 13, 16, 17),
  c(12, 13, 16, 18, 20, 19),
  c(12, 13, 16, 18, 20, 21),
  c(12, 13, 16, 18, 22, 24),
  c(12, 13, 16, 18, 22, 25),
  c(12, 13, 16, 18, 20, 23, 26)
)

# find those paths:
path <- with(pipenostics::m325testbench, {
  flowls(sender, acceptor)
})

path[[4]]
# [1] 12 13 11  8  6  7

}
}
\seealso{
\code{\link{m325testbench}} for example of topology of district heating
 system
}
